@@ -79,15 +79,15 @@ class Settings(object):
                 verbosity=self.vars.verbosity)
 
     def present(self, field):
-        if self.data.dict.get(field, False) is False:
-            return False
-        return True
+        if self.data.dict.get(field, False):
+            return True
+        return False
 
-    def get(self, field):
-        return self.data.dict.get(field, None)
+    def get(self, field, alternative=None):
+        return self.data.dict.get(field, alternative)
 
     def sanity(self, fields):
         missing = [f for f in fields if f not in self.data.dict]
         if missing:
             raise SettingsException('Not all mandatory fields present! Missing: %s' % ','.join(missing))
-        return True
\ No newline at end of file
+        return True
